@@ -1,16 +1,31 @@
 import tortilla
 from requests.auth import HTTPBasicAuth
+import requests.packages
 
 
 class MinimalConfluence:
-    def __init__(self, host, username, password):
-        self.host = host
-        self.username = username
-        self.password = password
+    def __init__(self, host, username=None, password=None, token=None, verify=True):
+        if token is not None:
+            self.api = tortilla.wrap(
+                host,
+                verify=verify,
+            )
+            self.api.config.headers.Authorization = f"Bearer {token}"
+        elif username is not None and password is not None:
+            self.api = tortilla.wrap(
+                host,
+                auth=HTTPBasicAuth(username, password),
+                verify=verify,
+            )
+        else:
+            raise ValueError(
+                "Either a personal access token, or username and password are required"
+            )
 
-        self.api = tortilla.wrap(
-            self.host, auth=HTTPBasicAuth(self.username, self.password)
-        )
+        if not verify:
+            requests.packages.urllib3.disable_warnings(
+                requests.packages.urllib3.exceptions.InsecureRequestWarning
+            )
 
     def get_page(self, title=None, space_key=None, page_id=None):
         if page_id is not None:
